@@ -23,7 +23,7 @@ __copyright__ = '(C) 2017, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 
 import os
@@ -98,7 +98,7 @@ class GridInverseDistanceNearestNeighbor(GdalAlgorithm):
                                                        self.tr('Maximum number of data points to use'),
                                                        type=QgsProcessingParameterNumber.Integer,
                                                        minValue=0,
-                                                       defaultValue=0))
+                                                       defaultValue=12))
         self.addParameter(QgsProcessingParameterNumber(self.MIN_POINTS,
                                                        self.tr('Minimum number of data points to use'),
                                                        type=QgsProcessingParameterNumber.Integer,
@@ -145,6 +145,9 @@ class GridInverseDistanceNearestNeighbor(GdalAlgorithm):
     def icon(self):
         return QIcon(os.path.join(pluginPath, 'images', 'gdaltools', 'grid.png'))
 
+    def commandName(self):
+        return 'gdal_grid'
+
     def getConsoleCommands(self, parameters, context, feedback, executing=True):
         ogrLayer, layerName = self.getOgrCompatibleSource(self.INPUT, parameters, context, feedback, executing)
 
@@ -180,4 +183,4 @@ class GridInverseDistanceNearestNeighbor(GdalAlgorithm):
         arguments.append(ogrLayer)
         arguments.append(out)
 
-        return ['gdal_grid', GdalUtils.escapeAndJoin(arguments)]
+        return [self.commandName(), GdalUtils.escapeAndJoin(arguments)]
