@@ -23,14 +23,15 @@ __copyright__ = '(C) 2015, Arnaud Morvan'
 
 # This will get replaced with a git SHA1 when you do a git archive323
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import os
 
 from qgis.PyQt.QtGui import QIcon
 from qgis.PyQt.QtCore import QVariant
 
-from qgis.core import (QgsSettings,
+from qgis.core import (QgsApplication,
+                       QgsSettings,
                        QgsGeometry,
                        QgsFeature,
                        QgsField,
@@ -39,6 +40,7 @@ from qgis.core import (QgsSettings,
                        QgsWkbTypes,
                        QgsFields,
                        QgsProcessing,
+                       QgsProcessingException,
                        QgsProcessingFeatureSource,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterEnum,
@@ -62,7 +64,10 @@ class CheckValidity(QgisAlgorithm):
     ERROR_COUNT = 'ERROR_COUNT'
 
     def icon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'ftools', 'check_geometry.png'))
+        return QgsApplication.getThemeIcon("/algorithms/mAlgorithmCheckGeometry.svg")
+
+    def svgIconPath(self):
+        return QgsApplication.iconPath("/algorithms/mAlgorithmCheckGeometry.svg")
 
     def group(self):
         return self.tr('Vector geometry')
@@ -121,6 +126,8 @@ class CheckValidity(QgisAlgorithm):
 
     def doCheck(self, method, parameters, context, feedback):
         source = self.parameterAsSource(parameters, self.INPUT_LAYER, context)
+        if source is None:
+            raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT_LAYER))
 
         (valid_output_sink, valid_output_dest_id) = self.parameterAsSink(parameters, self.VALID_OUTPUT, context,
                                                                          source.fields(), source.wkbType(), source.sourceCrs())
