@@ -24,9 +24,9 @@ __copyright__ = '(C) 2012, Anita Graser'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '8a899c8758b30adc3f8d6df682a5702dd3bfe6f0'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
-from qgis.core import (QgsProcessingParameterNumber,
+from qgis.core import (QgsProcessingParameterDistance,
                        QgsProcessing)
 
 from processing.algs.qgis.QgisAlgorithm import QgisFeatureBasedAlgorithm
@@ -50,9 +50,9 @@ class DensifyGeometriesInterval(QgisFeatureBasedAlgorithm):
         self.interval = None
 
     def initParameters(self, config=None):
-        self.addParameter(QgsProcessingParameterNumber(self.INTERVAL,
-                                                       self.tr('Interval between vertices to add'), QgsProcessingParameterNumber.Double,
-                                                       1, False, 0, 10000000))
+        self.addParameter(QgsProcessingParameterDistance(self.INTERVAL,
+                                                         self.tr('Interval between vertices to add'),
+                                                         1, 'INPUT', False, 0, 10000000))
 
     def name(self):
         return 'densifygeometriesgivenaninterval'
