@@ -23,7 +23,7 @@ __copyright__ = '(C) 2010, Michael Minn'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import os
 import math
@@ -44,6 +44,7 @@ from qgis.core import (QgsApplication,
                        QgsProcessingParameterEnum,
                        QgsProcessingParameterExtent,
                        QgsProcessingParameterNumber,
+                       QgsProcessingParameterDistance,
                        QgsProcessingParameterCrs,
                        QgsProcessingParameterFeatureSink,
                        QgsFields)
@@ -64,7 +65,10 @@ class Grid(QgisAlgorithm):
     OUTPUT = 'OUTPUT'
 
     def icon(self):
-        return QgsApplication.getThemeIcon("/vector_grid.svg")
+        return QgsApplication.getThemeIcon("/algorithms/mAlgorithmCreateGrid.svg")
+
+    def svgIconPath(self):
+        return QgsApplication.iconPath("/algorithms/mAlgorithmCreateGrid.svg")
 
     def tags(self):
         return self.tr('grid,lines,polygons,vector,create,fishnet,diamond,hexagon').split(',')
@@ -90,18 +94,18 @@ class Grid(QgisAlgorithm):
 
         self.addParameter(QgsProcessingParameterExtent(self.EXTENT, self.tr('Grid extent')))
 
-        self.addParameter(QgsProcessingParameterNumber(self.HSPACING,
-                                                       self.tr('Horizontal spacing'), QgsProcessingParameterNumber.Double,
-                                                       0.0001, False, 0, 1000000000.0))
-        self.addParameter(QgsProcessingParameterNumber(self.VSPACING,
-                                                       self.tr('Vertical spacing'), QgsProcessingParameterNumber.Double,
-                                                       0.0001, False, 0, 1000000000.0))
-        self.addParameter(QgsProcessingParameterNumber(self.HOVERLAY,
-                                                       self.tr('Horizontal overlay'), QgsProcessingParameterNumber.Double,
-                                                       0.0, False, 0, 1000000000.0))
-        self.addParameter(QgsProcessingParameterNumber(self.VOVERLAY,
-                                                       self.tr('Vertical overlay'), QgsProcessingParameterNumber.Double,
-                                                       0.0, False, 0, 1000000000.0))
+        self.addParameter(QgsProcessingParameterDistance(self.HSPACING,
+                                                         self.tr('Horizontal spacing'),
+                                                         0.0001, self.CRS, False, 0, 1000000000.0))
+        self.addParameter(QgsProcessingParameterDistance(self.VSPACING,
+                                                         self.tr('Vertical spacing'),
+                                                         0.0001, self.CRS, False, 0, 1000000000.0))
+        self.addParameter(QgsProcessingParameterDistance(self.HOVERLAY,
+                                                         self.tr('Horizontal overlay'),
+                                                         0.0, self.CRS, False, 0, 1000000000.0))
+        self.addParameter(QgsProcessingParameterDistance(self.VOVERLAY,
+                                                         self.tr('Vertical overlay'),
+                                                         0.0, self.CRS, False, 0, 1000000000.0))
 
         self.addParameter(QgsProcessingParameterCrs(self.CRS, 'Grid CRS', 'ProjectCrs'))
 
@@ -155,6 +159,8 @@ class Grid(QgisAlgorithm):
             outputWkb = QgsWkbTypes.Polygon
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
                                                fields, outputWkb, crs)
+        if sink is None:
+            raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
         if idx == 0:
             self._pointGrid(
