@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014, Arnaud Morvan'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '307d082e3de804064a7295aa079ee6cd0e47845a'
+__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
 
 import os
 from collections import OrderedDict
@@ -36,6 +36,7 @@ from qgis.PyQt.QtCore import (
     QVariant,
     Qt,
     pyqtSlot,
+    QCoreApplication
 )
 from qgis.PyQt.QtWidgets import (
     QComboBox,
@@ -45,6 +46,8 @@ from qgis.PyQt.QtWidgets import (
     QMessageBox,
     QSpinBox,
     QStyledItemDelegate,
+    QWidget,
+    QVBoxLayout
 )
 
 from qgis.core import (
@@ -58,8 +61,9 @@ from qgis.core import (
 )
 from qgis.gui import QgsFieldExpressionWidget
 
-from processing.gui.wrappers import WidgetWrapper, DIALOG_STANDARD, DIALOG_MODELER
+from processing.gui.wrappers import WidgetWrapper, DIALOG_STANDARD, DIALOG_MODELER, DIALOG_BATCH
 from processing.tools import dataobjects
+from processing.algs.qgis.FieldsMapper import FieldsMapper
 
 
 pluginPath = os.path.dirname(__file__)
@@ -141,7 +145,10 @@ class FieldsMappingModel(QAbstractTableModel):
     def rowCount(self, parent=QModelIndex()):
         if parent.isValid():
             return 0
-        return self._mapping.__len__()
+        try:
+            return len(self._mapping)
+        except TypeError:
+            return 0
 
     def headerData(self, section, orientation, role=Qt.DisplayRole):
         if role == Qt.DisplayRole:
@@ -318,6 +325,8 @@ class FieldsMappingPanel(BASE, WIDGET):
             delegate)
 
     def setLayer(self, layer):
+        if self.model.layer() == layer:
+            return
         self.model.setLayer(layer)
         if layer is None:
             return
@@ -472,10 +481,35 @@ class FieldsMappingWidgetWrapper(WidgetWrapper):
         super(FieldsMappingWidgetWrapper, self).__init__(*args, **kwargs)
         self._layer = None
 
+    def createPanel(self):
+        return FieldsMappingPanel()
+
     def createWidget(self):
-        panel = FieldsMappingPanel()
-        panel.dialogType = self.dialogType
-        return panel
+        self.panel = self.createPanel()
+        self.panel.dialogType = self.dialogType
+
+        if self.dialogType == DIALOG_MODELER:
+            self.combobox = QComboBox()
+            self.combobox.addItem(QCoreApplication.translate('Processing', '[Preconfigure]'), None)
+            fieldsMappingInputs = self.dialog.getAvailableValuesOfType(FieldsMapper.ParameterFieldsMapping)
+            for input in fieldsMappingInputs:
+                self.combobox.addItem(self.dialog.resolveValueDescription(input), input)
+
+            def updatePanelEnabledState():
+                if self.combobox.currentData() is None:
+                    self.panel.setEnabled(True)
+                else:
+                    self.panel.setEnabled(False)
+
+            self.combobox.currentIndexChanged.connect(updatePanelEnabledState)
+
+            widget = QWidget()
+            widget.setLayout(QVBoxLayout())
+            widget.layout().addWidget(self.combobox)
+            widget.layout().addWidget(self.panel)
+            return widget
+        else:
+            return self.panel
 
     def postInitialize(self, wrappers):
         for wrapper in wrappers:
@@ -506,10 +540,16 @@ class FieldsMappingWidgetWrapper(WidgetWrapper):
         if not isinstance(layer, QgsVectorLayer):
             layer = None
         self._layer = layer
-        self.widget.setLayer(self._layer)
+        self.panel.setLayer(self._layer)
 
     def setValue(self, value):
-        self.widget.setValue(value)
+        self.panel.setValue(value)
 
     def value(self):
-        return self.widget.value()
+        if self.dialogType == DIALOG_MODELER:
+            if self.combobox.currentData() is None:
+                return self.panel.value()
+            else:
+                return self.comboValue(combobox=self.combobox)
+        else:
+            return self.panel.value()
